/*
*  example program to read the HP 34401 DVM. Program will 
*  initialize the meter, and then make successive reads until the
*  user hits any key.
*    Command line parameters:
*         hpexamp <range> <res> <trig_mode>
*            range - full scale range (in volts) defaults to 5.
*            res   - resolution (in volts) defaults to .0001
*            trig_mode - 0 -> immediate triggers
*                        1 -> external triggers
*                     defaults to 1
*/

#include <stdio.h>
#include <stdlib.h>

/* default values for the readout parameters (overriden by
  command line) */

float hpdvm_range=5.;
float hpdvm_res=.0001;
int hpdvm_trig_mode=0;

/* headers for the hpdvm library */
#include <hpdvm.h>

int main(int argc, char** argv)
{

int stat;
double voltage;

/* get any command line parameters */
if(argc>1)
  {
  hpdvm_range = atof(argv[1]);
  if(argc>2)
    {
    hpdvm_res = atof(argv[2]);
    if(argc>3)
      {
      hpdvm_trig_mode = atoi(argv[3]);
      }
    }
  }

/* initialize the DVM */

   printf("Setting up HPDVM with: range=%f, res=%f, Trig mode: ",
     hpdvm_range,hpdvm_res);
   
   if(hpdvm_trig_mode==0) 
     printf("IMMediate.\n");
   else
     printf("EXTernal.\n");

     
   stat = hpdvm_init_voltread(hpdvm_range,
                             hpdvm_res,
                             hpdvm_trig_mode);
   if(stat==-1)
     {
     printf("Error! GPIP error occured during HP initialization.\n");
     exit(0);
     }
   if(stat==-2)
     {
     printf("Error! HP DVM error occured during initialization.\n");
     exit(0);
     }

  printf("Initialization successful. Going into read loop.\n");
  printf("Hit any key to terminate...\n");
/*
  read until user hits the keyboard
*/
   do
     {
     stat = hpdvm_read(&voltage);
     if(stat<0) 
       {
       printf("Error! Fatal error during HPDVM read.\n");
       exit(0);
       }
     if(stat==0)
       {
       printf("HPDVM reads: %f V\n",voltage);
       }
     else
       {
       printf("HPDVM timed out waiting for trigger. Will try again.\n");
       }
     } while (1);
 exit(1);
}
