/************************************************************************/
/* Example program to set up the LeCroy 9210 Pulser using the National  */
/* Instruments 1014 VME/GPIB interface.  This program must be linked    */
/* to the esp488.o library.                                             */
/*                                                                      */
/*  5/5/98 E.Prebys Original                                            */
/************************************************************************/

#include <stdio.h>
#include <stdlib.h>

#define GPIB_ERR (0x8000)  /* Gpib error bit */

typedef unsigned char byte;

int pulser_add=8;        /* Gpib address of pulser */
byte wr_buff[256];       /* write buffer */
byte rd_buff[256];       /* read buffer */

char pulser_id[] = "LECROY,9210"; /* first part of pulser ID string */

extern unsigned ibsta,ibcnt;  
                         /* status and count variables filled in esp488.c */

/* Main program */
int main(int argc, char **argv)
{
  int maxrd;
  maxrd = sizeof(rd_buff) -1 ; /* leave room for string termination */

  /********** Initialize the interface *****/
  if(ibinit()&GPIB_ERR) {
    fprintf(stderr,"Error initializing Interface.\n");
    exit(-1);
  }

  /**********Initialize Pulser ****/
  /* set to write to pulser */
  ibsetwr(pulser_add);
  ibwrt("*RST",4);    /* reset the pulser */
  ibwrt("*CLS",4);    /* reset the status */
  
  /**********Get Pulser ID string and verify ******/
  ibwrt("*IDN?",5);   /* Request device ID string */
  ibget();            /* Fetch response */
  ibsetrd(pulser_add); /* must explicitly switch direction to read */
  if(ibrd(rd_buff,maxrd)&GPIB_ERR) {
    fprintf(stderr,"Error during read. Status = 0x%4.4X, Count = %d.\n",
	    ibsta,ibcnt);
    exit(-2);
  }
  rd_buff[ibcnt] = '\0';  /* terminate string properly */

  printf("Pulser returns ID string %s",rd_buff);
  /* compare this to what's expected */
  if(strncmp(rd_buff,pulser_id,strlen(pulser_id))!=0) {
    fprintf(stderr,"Warning! ID string not what's expected (%s...)\n",
	    pulser_id);}

  /*****Print a message to the screen *****/
  ibsetwr(pulser_add);    /* set back to write */
  ibwrt("MSG \"Remote Pulser\nControl\"",28);

  /*****Set frequency ****/
  ibwrt("FREQ 10K",8);
  ibwrt("FREQ?",5);  /* Read back (this'll be the last time we do this) */
  ibget();
  ibsetrd(pulser_add);
  ibrd(rd_buff,maxrd);
  rd_buff[ibcnt] = '\0'; /*terminate string */
  strtok(rd_buff,"\n"); /* strip newline */
  printf("Frequency: %s Hz\n",rd_buff);
  ibsetwr(pulser_add);  /* set back to write */

  /***Setup pulses.  Make channel A a negative 100mV, 100ns pulse and
      channel B a positive 1V pulse ***/
  /*****Channel A*****/
  ibwrt("A:INV ON",8);   /* inverted */
  ibwrt("A:WID 100n",10);/* 100 ns wide */
  ibwrt("A:VHI 0.0",9);  /* "high" is GND */
  ibwrt("A:VLO -.5",9);  /* negative 500mV pulse */
  /*****Channel B*****/
  ibwrt("B:INV OFF",8);  /* no inversion */
  ibwrt("B:WID 500n",10);/* 500 ns wide */
  ibwrt("B:VLO 0.0",9);  /* low is GND */
  ibwrt("B:VHI 1.0",9);  /* positive 1V pulse */
  /*****Enable both channels */
  ibwrt("A:DISA OFF",10);
  ibwrt("B:DISA OFF",10);
  exit(0);

}
